/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.demo.jee6.web;

import java.io.IOException;
import java.util.Properties;

import javax.ejb.CreateException;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;
import javax.servlet.ServletException;
import javax.servlet.annotation.HttpConstraint;
import javax.servlet.annotation.HttpMethodConstraint;
import javax.servlet.annotation.ServletSecurity;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jboss.demo.j2ee14.ejb.PojoProcessorRemote;
import org.jboss.demo.j2ee14.ejb.PojoProcessorRemoteHome;
import org.jboss.demo.j2ee14.ejb.SerializablePojo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author steve.coy
 * 
 */
@ServletSecurity(value = @HttpConstraint(ServletSecurity.EmptyRoleSemantic.DENY),
                 httpMethodConstraints = { @HttpMethodConstraint(value = "GET",
                                                                 rolesAllowed = { "user" }) })
@WebServlet(urlPatterns = { "/test" })
public class EjbClientServlet extends HttpServlet {

    private static final long serialVersionUID = -7516665340586967415L;

    private final Logger logger = LoggerFactory.getLogger(EjbClientServlet.class);

    private Properties remoteProperties = new Properties();

    /*
     * (non-Javadoc)
     * 
     * @see javax.servlet.GenericServlet#init()
     */
    @Override
    public void init() throws ServletException {
        remoteProperties.put(Context.INITIAL_CONTEXT_FACTORY, "org.jnp.interfaces.NamingContextFactory");
        remoteProperties.put(Context.URL_PKG_PREFIXES, "org.jboss.naming:org.jnp.interfaces");
        remoteProperties.put(Context.PROVIDER_URL, "jnp://localhost:1199");
    }

    /*
     * (non-Javadoc)
     * 
     * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
     */
    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        try {
            logger.info("Setting up to call a PojoProcessor running in JBossAS 4.0.x");
            
            Context initialContext = new InitialContext(remoteProperties);
            Object pojoProcessorHomeObject = initialContext.lookup("demo/PojoProcessorHome");
            
            // This seems to be redundant, but that is probably an implementation detail
            PojoProcessorRemoteHome remoteHome = (PojoProcessorRemoteHome) PortableRemoteObject.narrow(pojoProcessorHomeObject,
                    PojoProcessorRemoteHome.class);
            
            PojoProcessorRemote pojoProcessor = remoteHome.create();
            pojoProcessor.process(new SerializablePojo(100, "Hello JBoss 4.0!"));
            resp.getWriter().println("OK");

        } catch (NamingException e) {
            logger.error("Failed to lookup remote ejb home", e);
            throw new ServletException("Failed to lookup remote ejb home", e);
        } catch (CreateException e) {
            logger.error("Failed to create remote home interface", e);
            throw new ServletException("Failed to create remote home interface", e);
        }

    }

}
